@@ -18,7 +18,7 @@ BEGIN {
 }
 use namespace::autoclean;
 
-our $VERSION = "0.09";
+our $VERSION = "0.010";
 
 use MooseX::Types -declare => [qw(
     ISO8601DateStr
@@ -110,7 +110,7 @@ subtype ISO8601DateTimeDurationStr,
         from DateTime,
             via { $coerce{$type_name}->($_) },
         from Num,
-            via { $coerce{$type_name}->(DateTime->from_epoch( epoch => $_ )) };
+            via { $coerce{$type_name}->(DT->from_epoch( epoch => $_ )) };
 
         if ($MYSQL) {
             coerce $type_name, from MySQLDateTime(),
